==> BSgenome.Dmelanogaster.UCSC.dm3_1.3.17.tar.gz: BSgenome.Dmelanogaster.UCSC.dm3/man/package.Rd <==
\name{Dmelanogaster}
\docType{package}

\alias{BSgenome.Dmelanogaster.UCSC.dm3-package}
\alias{BSgenome.Dmelanogaster.UCSC.dm3}
\alias{Dmelanogaster}


\title{Drosophila melanogaster (Fly) full genome (UCSC version dm3)}

\description{
  Drosophila melanogaster (Fly) full genome as provided by UCSC (dm3, Apr. 2006) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
sequences: chromFa.tar.gz, upstream1000.fa.gz, upstream2000.fa.gz, upstream5000.fa.gz
from http://hgdownload.cse.ucsc.edu/goldenPath/dm3/bigZips/
AGAPS masks: all the chr*_gap.txt.gz files from ftp://hgdownload.cse.ucsc.edu/goldenPath/dm3/database/
RM masks: http://hgdownload.cse.ucsc.edu/goldenPath/dm3/bigZips/chromOut.tar.gz
TRF masks: http://hgdownload.cse.ucsc.edu/goldenPath/dm3/bigZips/chromTrf.tar.gz
  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Dmelanogaster
seqlengths(Dmelanogaster)
Dmelanogaster$chr2L  # same as Dmelanogaster[["chr2L"]]

if ("AGAPS" \%in\% masknames(Dmelanogaster)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Dmelanogaster)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Dmelanogaster[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}

==> BSgenome.Dmelanogaster.UCSC.dm3_1.3.19.tar.gz: BSgenome.Dmelanogaster.UCSC.dm3/man/package.Rd <==
\name{BSgenome.Dmelanogaster.UCSC.dm3}
\docType{package}

\alias{BSgenome.Dmelanogaster.UCSC.dm3-package}
\alias{BSgenome.Dmelanogaster.UCSC.dm3}
\alias{Dmelanogaster}

\title{Drosophila melanogaster (Fly) full genome (UCSC version dm3)}

\description{
  Drosophila melanogaster (Fly) full genome as provided by UCSC (dm3, Apr. 2006) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
sequences: chromFa.tar.gz, upstream1000.fa.gz, upstream2000.fa.gz, upstream5000.fa.gz
from http://hgdownload.cse.ucsc.edu/goldenPath/dm3/bigZips/
AGAPS masks: all the chr*_gap.txt.gz files from ftp://hgdownload.cse.ucsc.edu/goldenPath/dm3/database/
RM masks: http://hgdownload.cse.ucsc.edu/goldenPath/dm3/bigZips/chromOut.tar.gz
TRF masks: http://hgdownload.cse.ucsc.edu/goldenPath/dm3/bigZips/chromTrf.tar.gz
  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{The Bioconductor Dev Team}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
BSgenome.Dmelanogaster.UCSC.dm3
genome <- BSgenome.Dmelanogaster.UCSC.dm3
seqlengths(genome)
genome$chr2L  # same as genome[["chr2L"]]

if ("AGAPS" \%in\% masknames(genome)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(genome)) {
    cat("Checking sequence", seqname, "... ")
    seq <- genome[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}
